get_performance_metrics: The function that is responsible for computing the...

Description Usage Arguments Value

Description

The function that is responsible for computing the performance evaluation metrics

Usage

1
get_performance_metrics(actuals, test, model)

Arguments

actuals

A vector containing the true class of the test data points

test

a dataframe. Test dataset

model

a r model. A trained classifier model whose performance is to be evaluated

Value

a vector with al the performance measures computed


rgopikrishnan91/DiscNoise documentation built on May 6, 2019, 6:59 p.m.