Description Usage Arguments Value
The function that is responsible for computing the performance evaluation metrics
1 | get_performance_metrics(actuals, test, model)
|
actuals |
A vector containing the true class of the test data points |
test |
a dataframe. Test dataset |
model |
a r model. A trained classifier model whose performance is to be evaluated |
a vector with al the performance measures computed
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.